@@ -299,6 +299,7 @@ pub struct Plotter<'a> {
     xmarkers: Vec<f64>,
     ymarkers: Vec<f64>,
     num_css_classes: Option<usize>,
+    preserve_aspect:bool
 }
 
 impl<'a> Plotter<'a> {
@@ -321,6 +322,7 @@ impl<'a> Plotter<'a> {
             xmarkers: Vec::new(),
             ymarkers: Vec::new(),
             num_css_classes: Some(8),
+            preserve_aspect:false
         }
     }
     /// Create a line from plots using a SVG polyline element.
@@ -452,6 +454,14 @@ impl<'a> Plotter<'a> {
         self
     }
 
+    ///
+    /// Preserve the aspect ratio by drawing a smaller graph in the same area.
+    /// 
+    pub fn preserve_aspect(&mut self)->&mut Self{
+        self.preserve_aspect=true;
+        self
+    }
+    
     ///
     /// The number of distinct css classes. If there are more plots than
     /// classes, then they will wrap around. The default value is 8.
@@ -470,6 +480,8 @@ impl<'a> Plotter<'a> {
         self
     }
 
+
+
     ///
     /// Use the plot iterators to write out the graph elements.
     /// Does not add a svg tag, or any styling elements.
@@ -536,6 +548,7 @@ impl<'a> Plotter<'a> {
         });
         w.into_writer()
     }
+
 }
 
 /// Shorthand for `moveable_format(move |w|write!(w,...))`
